package com.example.wearapp

import android.content.Intent
import android.content.SharedPreferences
import androidx.appcompat.app.AppCompatActivity
import android.os.Bundle
import android.util.Log
import android.view.View
import android.widget.Toast
import com.example.wearapp.common.Utils
import com.example.wearapp.databinding.ActivitySignBinding
import com.example.wearapp.network.RetrofitBuild
import com.example.wearapp.network.models.Token
import io.paperdb.Paper
import retrofit2.Call
import retrofit2.Callback
import retrofit2.Response
import java.util.regex.Pattern

class SignInActivity : AppCompatActivity() {

    lateinit var sharedPreferences: SharedPreferences
    lateinit var editor: SharedPreferences.Editor
    lateinit var uuId:String
    private val pattern = "[a-z0-9]{1,100}" +
            "\\@" +
            "[a-z]{1,30}" +
            "\\." +
            "[a-z]{1,10}"


    fun emailValid(text:String):Boolean{
        return Pattern.compile(pattern).matcher(text).matches()
    }

    private lateinit var binding: ActivitySignBinding
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        binding = ActivitySignBinding.inflate(layoutInflater)
        setContentView(binding.root)
        val zap = RetrofitBuild().retrofitBuilder()
        Paper.init(this)
        uuId = Paper.book().read("uuId","")!!
        sharedPreferences = getSharedPreferences("main", MODE_PRIVATE)
        editor = sharedPreferences.edit()
    }

    fun login(view: View) {
        if (binding.email.text.isNotEmpty() && binding.password.text.isNotEmpty()){
            if (emailValid(binding.email.text.toString())){
                RetrofitBuild().retrofitBuilder().login(
                    email = binding.email.text.toString(),
                    password = binding.password.text.toString(),
                    uuid =  uuId
                ).enqueue(object : Callback<Token> {
                    override fun onResponse(call: Call<Token>, response: Response<Token>) {
                        if (response.isSuccessful){
                            val intent = Intent(this@SignInActivity,MenuActivity::class.java)
                            startActivity(intent)
                            editor.putString("token", response.body()?.token)
                            editor.apply()
                            response.body()?.let { Paper.book().write("token", it.token) }
                        }
                        else{
                            Toast.makeText(this@SignInActivity, response.message(), Toast.LENGTH_SHORT).show()
                        }
                    }

                    override fun onFailure(call: Call<Token>, t: Throwable) {
                        Log.e("Login error",t.localizedMessage)
                        Toast.makeText(this@SignInActivity, t.localizedMessage, Toast.LENGTH_SHORT).show()
                    }
                })
            }else{
                Utils.AlertBuild("Error","Email error",this)
            }

        }else{
            Utils.AlertBuild("Error","Empty",this)
        }
    }
}